@@ -34,7 +34,8 @@
 
 #define MIXER			"mixer"
 #define CACHE_SIZE		"cache_size"
-#define PLUGIN_CACHE_SIZE		"plugin_cache_size"
+#define PLUGIN_AUDIO_CACHE_SIZE		"plugin_audio_cache_size"
+#define PLUGIN_VIDEO_CACHE_SIZE		"plugin_video_cache_size"
 #define OSDLEVEL		"osdlevel"
 #define PPLEVEL			"pplevel"
 #define SOFTVOL			"softvol"
@@ -172,6 +173,7 @@ typedef struct _IdleData {
     gboolean showcontrols;
     gdouble position;
     gdouble length;
+    gdouble start_time;
     glong byte_pos;
     gint chapters;
     gint brightness;
@@ -293,7 +295,8 @@ gint max_buckets[METER_BARS];
 
 gchar *lastfile;
 gint cache_size;
-gint plugin_cache_size;
+gint plugin_audio_cache_size;
+gint plugin_video_cache_size;
 gboolean forcecache;
 gint osdlevel;
 gint pplevel;
@@ -301,6 +304,7 @@ gint streaming;
 gint showcontrols;
 gboolean showsubtitles;
 gint fullscreen;
+gint init_fullscreen;
 gint videopresent;
 gint playlist;
 gint embed_window;
@@ -357,6 +361,8 @@ gboolean details_visible;
 gboolean restore_playlist;
 gboolean restore_details;
 gboolean restore_info;
+gboolean restore_controls;
+gboolean update_control_flag;
 gint restore_pane;
 gboolean disable_ass;
 gboolean disable_embeddedfonts;
@@ -526,4 +532,8 @@ GtkRecentManager *recent_manager;
 void recent_manager_changed_callback(GtkRecentManager * recent_manager, gpointer data);
 #endif
 
+GValue ALLOW_SHRINK_TRUE;
+GValue ALLOW_SHRINK_FALSE;
+
+
 #endif                          /* _COMMON_H */
