@@ -654,6 +654,8 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                                           "    <method name=\"GetBitrate\">\n"
                                           "        <arg name=\"url\" type=\"s\" />\n"
                                           "    </method>\n"
+                                          "    <method name=\"GetURI\">\n"
+                                          "    </method>\n"
                                           "    <signal name=\"Open\">\n"
                                           "        <arg name=\"url\" type=\"s\" />\n"
                                           "    </signal>\n"
@@ -741,10 +743,31 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetCacheSize")) {
                     reply_message = dbus_message_new_method_return(message);
-                    dbus_message_append_args(reply_message, DBUS_TYPE_INT32, &plugin_cache_size,
-                                             DBUS_TYPE_INVALID);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_INT32,
+                                             &plugin_video_cache_size, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
+                    cache_size = plugin_video_cache_size;
+                    return DBUS_HANDLER_RESULT_HANDLED;
+                }
+                if (dbus_message_is_method_call
+                    (message, "com.gnome.mplayer", "GetPluginAudioCacheSize")) {
+                    reply_message = dbus_message_new_method_return(message);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_INT32,
+                                             &plugin_audio_cache_size, DBUS_TYPE_INVALID);
+                    dbus_connection_send(connection, reply_message, NULL);
+                    dbus_message_unref(reply_message);
+                    cache_size = plugin_audio_cache_size;
+                    return DBUS_HANDLER_RESULT_HANDLED;
+                }
+                if (dbus_message_is_method_call
+                    (message, "com.gnome.mplayer", "GetPluginVideoCacheSize")) {
+                    reply_message = dbus_message_new_method_return(message);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_INT32,
+                                             &plugin_video_cache_size, DBUS_TYPE_INVALID);
+                    dbus_connection_send(connection, reply_message, NULL);
+                    dbus_message_unref(reply_message);
+                    cache_size = plugin_video_cache_size;
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetPlayState")) {
@@ -771,6 +794,16 @@ static DBusHandlerResult filter_func(DBusConnection * connection,
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
+                if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetURI")) {
+                    reply_message = dbus_message_new_method_return(message);
+                    s = g_strdup(idledata->info);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_STRING, &s,
+                                             DBUS_TYPE_INVALID);
+                    dbus_connection_send(connection, reply_message, NULL);
+                    dbus_message_unref(reply_message);
+                    return DBUS_HANDLER_RESULT_HANDLED;
+                }
+                printf("Unable to find method call\n");
             } else {
                 if (verbose)
                     printf("path didn't match - %s\n", dbus_message_get_path(message));
@@ -1003,8 +1036,8 @@ void dbus_send_event(gchar * event, gint button)
     if (connection != NULL && control_id != 0) {
         path = g_strdup_printf("/control/%i", control_id);
         localevent = g_strdup_printf("%s", event);
-        if (verbose) {
-            //printf("Posting Event %s\n",localevent);
+        if (verbose > 1) {
+            printf("Posting Event %s\n", localevent);
         }
         message = dbus_message_new_signal(path, "com.gecko.mediaplayer", "Event");
         dbus_message_append_args(message, DBUS_TYPE_STRING, &localevent, DBUS_TYPE_INT32,
@@ -1134,7 +1167,7 @@ void dbus_enable_screensaver()
 
         if (use_xscrnsaver) {
 #ifdef XSCRNSAVER_ENABLED
-            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(window->window), FALSE);
+            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(get_window(window)), FALSE);
 #endif
 
         } else {
@@ -1176,7 +1209,7 @@ void dbus_disable_screensaver()
         if (use_xscrnsaver) {
 
 #ifdef XSCRNSAVER_ENABLED
-            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(window->window), TRUE);
+            XScreenSaverSuspend(GDK_WINDOW_XDISPLAY(get_window(window)), TRUE);
 #endif
 
         } else {
