@@ -24,7 +24,7 @@
 //#include <X11/Xlib.h>
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
@@ -44,6 +44,7 @@
 GtkWidget *window;
 GdkWindow *window_container;
 GtkWidget *fs_window;
+GtkWidget *fs_controls;
 
 GtkWidget *menubar;
 GtkMenuItem *menuitem_file;
@@ -78,6 +79,8 @@ GtkMenuItem *menuitem_edit;
 GtkMenu *menu_edit;
 GtkMenuItem *menuitem_edit_random;
 GtkMenuItem *menuitem_edit_loop;
+GtkWidget *repeat;
+GtkWidget *shuffle;
 GtkMenuItem *menuitem_edit_switch_audio;
 GtkMenuItem *menuitem_edit_select_audio_lang;
 GtkMenu *menu_edit_audio_langs;
@@ -218,12 +221,13 @@ GtkWidget *image_prev;
 GtkWidget *image_menu;
 GtkWidget *image_fs;
 GtkWidget *image_icon;
-GtkTooltips *tooltip;
-GtkTooltips *volume_tip;
 
 #ifdef GTK2_12_ENABLED
 GtkStatusIcon *status_icon;
 GtkWidget *config_show_status_icon;
+#else
+GtkTooltips *tooltip;
+GtkTooltips *volume_tip;
 #endif
 
 GtkWidget *config_vo;
@@ -233,7 +237,8 @@ GtkWidget *config_audio_channels;
 GtkWidget *config_use_hw_audio;
 GtkWidget *config_volume;
 GtkWidget *config_cachesize;
-GtkWidget *config_plugin_cache_size;
+GtkWidget *config_plugin_audio_cache_size;
+GtkWidget *config_plugin_video_cache_size;
 GtkWidget *config_osdlevel;
 GtkWidget *config_deinterlace;
 GtkWidget *config_framedrop;
@@ -350,3 +355,10 @@ gboolean set_software_volume(int *data);
 
 gint get_height();
 gint get_width();
+
+void show_fs_controls();
+void hide_fs_controls();
+
+// GSEAL accessors
+void get_allocation(GtkWidget * widget, GtkAllocation * allocation);
+GdkWindow *get_window(GtkWidget * widget);
