@@ -23,7 +23,7 @@
  */
 
 #ifdef HAVE_CONFIG_H
-#  include <config.h>
+#include <config.h>
 #endif
 
 #include <sys/types.h>
@@ -57,7 +57,7 @@ static GOptionEntry entries[] = {
     {"verbose", 'v', 0, G_OPTION_ARG_NONE, &verbose, N_("Show more output on the console"), NULL},
     {"reallyverbose", '\0', 0, G_OPTION_ARG_NONE, &reallyverbose,
      N_("Show even more output on the console"), NULL},
-    {"fullscreen", 0, 0, G_OPTION_ARG_NONE, &fullscreen, N_("Start in fullscreen mode"), NULL},
+    {"fullscreen", 0, 0, G_OPTION_ARG_NONE, &init_fullscreen, N_("Start in fullscreen mode"), NULL},
     {"softvol", 0, 0, G_OPTION_ARG_NONE, &softvol, N_("Use mplayer software volume control"), NULL},
     {"remember_softvol", 0, 0, G_OPTION_ARG_NONE, &remember_softvol,
      N_("When set to TRUE the last volume level is set as the default"), NULL},
@@ -260,6 +260,8 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     } else {
         if (verbose > 1)
             printf("iter is invalid, nothing to play\n");
+        g_free(thread_data);
+        thread_data = NULL;
         return 0;
     }
 
@@ -281,7 +283,7 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     if (!streaming_media(uri) && !device_name(uri)) {
         i = 0;
         if (playable) {
-            while (demuxer == NULL && i < 10) {
+            while (demuxer == NULL && i < 50) {
                 g_free(title);
                 g_free(artist);
                 g_free(album);
@@ -592,7 +594,6 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         autostart = 1;
     }
 
-
     return 0;
 }
 
@@ -697,6 +698,7 @@ int main(int argc, char *argv[])
     subtitle_color = NULL;
     subtitle_outline = FALSE;
     subtitle_shadow = FALSE;
+    disable_embeddedfonts = FALSE;
     quit_on_complete = FALSE;
     slide_away = NULL;
     verbose = 0;
@@ -744,6 +746,8 @@ int main(int argc, char *argv[])
     save_loc = TRUE;
     use_xscrnsaver = FALSE;
     screensaver_disabled = FALSE;
+    update_control_flag = FALSE;
+    gchar *filename;
 
     sa.sa_handler = hup_handler;
     sigemptyset(&sa.sa_mask);
@@ -759,6 +763,11 @@ int main(int argc, char *argv[])
     // call g_type_init or otherwise we can crash
     g_type_init();
 
+    g_value_init(&ALLOW_SHRINK_TRUE, G_TYPE_BOOLEAN);
+    g_value_init(&ALLOW_SHRINK_FALSE, G_TYPE_BOOLEAN);
+    g_value_set_boolean(&ALLOW_SHRINK_FALSE, FALSE);
+    g_value_set_boolean(&ALLOW_SHRINK_TRUE, TRUE);
+
     uri = g_strdup_printf("%s/gnome-mplayer/cover_art", g_get_user_config_dir());
     if (!g_file_test(uri, G_FILE_TEST_IS_DIR)) {
         g_mkdir_with_parents(uri, 0775);
@@ -798,6 +807,7 @@ int main(int argc, char *argv[])
     show_notification = gm_pref_store_get_boolean(gm_store, SHOW_NOTIFICATION);
     show_status_icon = gm_pref_store_get_boolean(gm_store, SHOW_STATUS_ICON);
     showcontrols = gm_pref_store_get_boolean_with_default(gm_store, SHOW_CONTROLS, showcontrols);
+    restore_controls = showcontrols;
     disable_deinterlace = gm_pref_store_get_boolean(gm_store, DISABLEDEINTERLACE);
     disable_framedrop = gm_pref_store_get_boolean(gm_store, DISABLEFRAMEDROP);
     disable_fullscreen = gm_pref_store_get_boolean(gm_store, DISABLEFULLSCREEN);
@@ -887,12 +897,16 @@ int main(int argc, char *argv[])
     if (cache_size == 0)
         cache_size = 2000;
 
-    plugin_cache_size = gm_pref_store_get_int(gm_store, PLUGIN_CACHE_SIZE);
-    if (plugin_cache_size == 0)
-        plugin_cache_size = 2000;
+    plugin_audio_cache_size = gm_pref_store_get_int(gm_store, PLUGIN_AUDIO_CACHE_SIZE);
+    if (plugin_audio_cache_size == 0)
+        plugin_audio_cache_size = 2000;
+
+    plugin_video_cache_size = gm_pref_store_get_int(gm_store, PLUGIN_VIDEO_CACHE_SIZE);
+    if (plugin_video_cache_size == 0)
+        plugin_video_cache_size = 2000;
 
     if (control_id != 0)
-        cache_size = plugin_cache_size;
+        cache_size = plugin_video_cache_size;
 
     gm_pref_store_free(gm_store);
     gm_pref_store_free(gmp_store);
@@ -1007,7 +1021,19 @@ int main(int argc, char *argv[])
     retrieve_metadata_pool = g_thread_pool_new(retrieve_metadata, NULL, 10, TRUE, NULL);
 
     if (argv[fileindex] != NULL) {
+#ifdef GIO_ENABLED
+        file = g_file_new_for_commandline_arg(argv[fileindex]);
+        if (file != NULL) {
+            uri = g_file_get_uri(file);
+            g_object_unref(file);
+        }
+        filename = g_filename_from_uri(uri, NULL, NULL);
+        g_stat(filename, &buf);
+        g_free(filename);
+#else
         g_stat(argv[fileindex], &buf);
+#endif
+
         if (verbose) {
             printf("opening %s\n", argv[fileindex]);
             printf("is block %i\n", S_ISBLK(buf.st_mode));
@@ -1099,6 +1125,8 @@ int main(int argc, char *argv[])
             i = fileindex;
 
             while (argv[i] != NULL) {
+                if (verbose > 1)
+                    printf("Argument %i is %s\n", i, argv[i]);
 #ifdef GIO_ENABLED
                 if (!device_name(argv[i])) {
                     file = g_file_new_for_commandline_arg(argv[i]);
@@ -1153,7 +1181,6 @@ int main(int argc, char *argv[])
     }
 #endif
 
-
     dbus_hookup(embed_window, control_id);
     show_window(embed_window);
 
@@ -1196,7 +1223,7 @@ int main(int argc, char *argv[])
 
         }
     }
-
+                        
     safe_to_save_default_playlist = FALSE;
     if (use_defaultpl) {
         create_folder_progress_window();
