@@ -165,11 +165,11 @@ gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
      */
     if (selection_data == NULL)
         return FALSE;
-    if (selection_data->length < 0)
+    if (gtk_selection_data_get_length(selection_data) < 0)
         return FALSE;
 
     if ((info == DRAG_INFO_0) || (info == DRAG_INFO_1) || (info == DRAG_INFO_2)) {
-        list = g_uri_list_extract_uris((const gchar *) selection_data->data);
+        list = g_uri_list_extract_uris((const gchar *) gtk_selection_data_get_data(selection_data));
 
         while (list[i] != NULL) {
             if (strlen(list[i]) > 0) {
@@ -233,7 +233,11 @@ gboolean playlist_motion_callback(GtkWidget * widget, GdkEventMotion * event, gp
                 tip = g_strdup_printf(_("Filename: %s\nSubtitle: %s"), iterfilename, itersubtitle);
                 g_free(itersubtitle);
             }
+#ifdef GTK2_12_ENABLED
+            gtk_widget_set_tooltip_text(widget, tip);
+#else
             gtk_tooltips_set_tip(playlisttip, widget, tip, NULL);
+#endif
             g_free(tip);
             g_free(iterfilename);
         }
@@ -549,6 +553,9 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
     GSList *uris;
     gchar *last_dir;
     gchar *message;
+    gint count;
+
+    count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL);
 
     dialog = gtk_file_chooser_dialog_new(_("Choose Directory"),
                                          GTK_WINDOW(window),
@@ -594,7 +601,7 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
     g_free(message);
     g_idle_add(set_media_label, idledata);
 
-    if (data != NULL) {
+    if (count == 0 && filecount > 0) {
         gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
         play_iter(&iter, 0);
         dontplaynext = FALSE;
@@ -739,9 +746,22 @@ void playlist_close(GtkWidget * widget, void *data)
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_playlist), FALSE);
 }
 
+void repeat_callback(GtkWidget * widget, void *data)
+{
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_edit_loop), !loop);
+}
+
+void shuffle_callback(GtkWidget * widget, void *data)
+{
+    gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_edit_random),
+                                   !gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM
+                                                                   (menuitem_edit_random)));
+}
+
 void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
 {
     playlist_visible = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
+    gtk_tree_view_set_enable_search(GTK_TREE_VIEW(list), playlist_visible);
     if (remember_loc)
         use_remember_loc = TRUE;
     adjust_layout();
@@ -771,7 +791,10 @@ void create_playlist_widget()
     GtkWidget *undo;
     GtkTreePath *path;
     GtkAccelGroup *accel_group;
+#ifdef GTK2_12_ENABLED
+#else
     GtkTooltips *tooltip;
+#endif
     gchar *coltitle;
     gint count;
     GtkTargetEntry target_entry[3];
@@ -788,6 +811,7 @@ void create_playlist_widget()
     closebox = gtk_hbox_new(FALSE, 0);
 
     list = gtk_tree_view_new_with_model(GTK_TREE_MODEL(playliststore));
+    gtk_tree_view_set_enable_search(GTK_TREE_VIEW(list), FALSE);
     gtk_tree_view_set_reorderable(GTK_TREE_VIEW(list), FALSE);
     gtk_widget_add_events(list, GDK_BUTTON_PRESS_MASK);
     gtk_widget_set_size_request(GTK_WIDGET(list), -1, -1);
@@ -826,10 +850,12 @@ void create_playlist_widget()
 
     //Connect the signal for DnD
     g_signal_connect(GTK_OBJECT(plvbox), "drag_data_received",
-                     GTK_SIGNAL_FUNC(playlist_drop_callback), NULL);
-
+                     G_CALLBACK(playlist_drop_callback), NULL);
 
+#ifdef GTK2_12_ENABLED
+#else
     playlisttip = gtk_tooltips_new();
+#endif
 
     count = gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL);
     renderer = gtk_cell_renderer_text_new();
@@ -907,89 +933,130 @@ void create_playlist_widget()
 
 
     plclose = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(plclose, _("Close Playlist View"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, plclose, _("Close Playlist View"), NULL);
+#endif
     gtk_container_add(GTK_CONTAINER(plclose),
                       gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
 
-    g_signal_connect_swapped(GTK_OBJECT(plclose), "clicked", GTK_SIGNAL_FUNC(playlist_close), NULL);
+    g_signal_connect_swapped(GTK_OBJECT(plclose), "clicked", G_CALLBACK(playlist_close), NULL);
 
 
     loadlist = gtk_button_new();
+
+
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(loadlist, _("Open Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, loadlist, _("Open Playlist"), NULL);
+#endif
     gtk_container_add(GTK_CONTAINER(loadlist),
                       gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), loadlist, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(loadlist), "clicked", GTK_SIGNAL_FUNC(load_playlist), NULL);
+    g_signal_connect(GTK_OBJECT(loadlist), "clicked", G_CALLBACK(load_playlist), NULL);
 
     savelist = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(savelist, _("Save Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, savelist, _("Save Playlist"), NULL);
+#endif
     gtk_container_add(GTK_CONTAINER(savelist),
                       gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), savelist, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(savelist), "clicked", GTK_SIGNAL_FUNC(save_playlist), NULL);
+    g_signal_connect(GTK_OBJECT(savelist), "clicked", G_CALLBACK(save_playlist), NULL);
 
     add = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(add, _("Add Item to Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, add, _("Add Item to Playlist"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(add),
                          gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(add), "clicked", GTK_SIGNAL_FUNC(add_to_playlist), NULL);
+    g_signal_connect(GTK_OBJECT(add), "clicked", G_CALLBACK(add_to_playlist), NULL);
 
     remove = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(remove, _("Remove Item from Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, remove, _("Remove Item from Playlist"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(remove),
                          gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), remove, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(remove), "clicked", GTK_SIGNAL_FUNC(remove_from_playlist), list);
+    g_signal_connect(GTK_OBJECT(remove), "clicked", G_CALLBACK(remove_from_playlist), list);
 
     add_folder = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(add_folder, _("Add Items in Folder to Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, add_folder, _("Add Items in Folder to Playlist"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(add_folder),
                          gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add_folder, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(add_folder), "clicked", GTK_SIGNAL_FUNC(add_folder_to_playlist),
-                     list);
+    g_signal_connect(GTK_OBJECT(add_folder), "clicked", G_CALLBACK(add_folder_to_playlist), list);
 
     clear = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(clear, _("Clear Playlist"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, clear, _("Clear Playlist"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(clear),
                          gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), clear, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(clear), "clicked", GTK_SIGNAL_FUNC(clear_playlist), list);
+    g_signal_connect(GTK_OBJECT(clear), "clicked", G_CALLBACK(clear_playlist), list);
 
     up = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(up, _("Move Item Up"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, up, _("Move Item Up"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(up),
                          gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), up, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(up), "clicked", GTK_SIGNAL_FUNC(move_item_up), list);
+    g_signal_connect(GTK_OBJECT(up), "clicked", G_CALLBACK(move_item_up), list);
     gtk_widget_set_sensitive(up, FALSE);
 
     down = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(down, _("Move Item Down"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, down, _("Move Item Down"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(down),
                          gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), down, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(down), "clicked", GTK_SIGNAL_FUNC(move_item_down), list);
+    g_signal_connect(GTK_OBJECT(down), "clicked", G_CALLBACK(move_item_down), list);
     gtk_widget_set_sensitive(down, FALSE);
 
 
     undo = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(undo, _("UnSort List"));
+#else
     tooltip = gtk_tooltips_new();
     gtk_tooltips_set_tip(tooltip, undo, _("UnSort List"), NULL);
+#endif
     gtk_button_set_image(GTK_BUTTON(undo),
                          gtk_image_new_from_stock(GTK_STOCK_UNDO, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), undo, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(undo), "clicked", GTK_SIGNAL_FUNC(undo_playlist_sort), list);
+    g_signal_connect(GTK_OBJECT(undo), "clicked", G_CALLBACK(undo_playlist_sort), list);
     gtk_widget_set_sensitive(undo, TRUE);
 
 
@@ -998,7 +1065,39 @@ void create_playlist_widget()
     gtk_widget_add_accelerator(GTK_WIDGET(remove), "clicked",
                                accel_group, GDK_Delete, 0, GTK_ACCEL_VISIBLE);
 
+    repeat = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(repeat, _("Loop Playlist"));
+#else
+    tooltip = gtk_tooltips_new();
+    gtk_tooltips_set_tip(tooltip, repeat, _("Loop Playlist"), NULL);
+#endif
+    gtk_button_set_image(GTK_BUTTON(repeat),
+                         gtk_image_new_from_icon_name("media-playlist-repeat", GTK_ICON_SIZE_MENU));
+    gtk_box_pack_start(GTK_BOX(ctrlbox), repeat, FALSE, FALSE, 0);
+    g_signal_connect(GTK_OBJECT(repeat), "clicked", G_CALLBACK(repeat_callback), NULL);
+    gtk_widget_set_sensitive(repeat, TRUE);
+
+    shuffle = gtk_button_new();
+#ifdef GTK2_12_ENABLED
+    gtk_widget_set_tooltip_text(shuffle, _("Shuffle Playlist"));
+#else
+    tooltip = gtk_tooltips_new();
+    gtk_tooltips_set_tip(tooltip, shuffle, _("Shuffle Playlist"), NULL);
+#endif
+    gtk_button_set_image(GTK_BUTTON(shuffle),
+                         gtk_image_new_from_icon_name("media-playlist-shuffle",
+                                                      GTK_ICON_SIZE_MENU));
+    gtk_box_pack_start(GTK_BOX(ctrlbox), shuffle, FALSE, FALSE, 0);
+    g_signal_connect(GTK_OBJECT(shuffle), "clicked", G_CALLBACK(shuffle_callback), NULL);
+    gtk_widget_set_sensitive(shuffle, TRUE);
+
+
+#ifdef GTK2_18_ENABLED
+    gtk_widget_set_can_default(plclose, TRUE);
+#else
     GTK_WIDGET_SET_FLAGS(plclose, GTK_CAN_DEFAULT);
+#endif
     gtk_box_pack_end(GTK_BOX(closebox), plclose, FALSE, FALSE, 0);
 
     scrolled = gtk_scrolled_window_new(NULL, NULL);
