@@ -39,6 +39,12 @@ void mplayer_shutdown()
         }
         send_command("quit\n", FALSE);
         dbus_send_event("Ended", 0);
+    } else {
+        if (verbose > 1) {
+            printf
+                ("plugin calling mplayer shutdown when mplayer might have already been shutdown\n");
+        }
+        send_command("quit\n", FALSE);
     }
 
 }
@@ -75,7 +81,7 @@ gboolean send_command(gchar * command, gboolean retain_pause)
     } else {
         cmd = g_strdup(command);
     }
-
+    // printf("command = %s\n", cmd);
     g_idle_add(write_to_mplayer, (gpointer) cmd);
     return TRUE;
 
@@ -439,26 +445,30 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
             send_command("get_property sub_demux\n", TRUE);
         }
 
-        cmd = g_strdup_printf("brightness %i\n", idledata->brightness);
-        send_command(cmd, TRUE);
-        g_free(cmd);
+		if (embed_window == 0)
+			idledata->cachepercent = 0.0;
 
-        cmd = g_strdup_printf("contrast %i\n", idledata->contrast);
-        send_command(cmd, TRUE);
-        g_free(cmd);
+		if (g_ascii_strncasecmp(vo, "gl2", strlen("gl2")) != 0) {
+		    cmd = g_strdup_printf("brightness %i\n", idledata->brightness);
+		    send_command(cmd, TRUE);
+		    g_free(cmd);
 
-        cmd = g_strdup_printf("gamma %i\n", idledata->gamma);
-        send_command(cmd, TRUE);
-        g_free(cmd);
+		    cmd = g_strdup_printf("contrast %i\n", idledata->contrast);
+		    send_command(cmd, TRUE);
+		    g_free(cmd);
 
-        cmd = g_strdup_printf("hue %i\n", idledata->hue);
-        send_command(cmd, TRUE);
-        g_free(cmd);
+		    cmd = g_strdup_printf("gamma %i\n", idledata->gamma);
+		    send_command(cmd, TRUE);
+		    g_free(cmd);
 
-        cmd = g_strdup_printf("saturation %i\n", idledata->saturation);
-        send_command(cmd, TRUE);
-        g_free(cmd);
+		    cmd = g_strdup_printf("hue %i\n", idledata->hue);
+		    send_command(cmd, TRUE);
+		    g_free(cmd);
 
+		    cmd = g_strdup_printf("saturation %i\n", idledata->saturation);
+		    send_command(cmd, TRUE);
+		    g_free(cmd);
+		}
     }
 
     if (strstr(mplayer_output->str, "Video: no video") != NULL) {
@@ -491,9 +501,17 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         g_idle_add(set_progress_time, idledata);
     }
 
+    if (strstr(mplayer_output->str, "ID_START_TIME") != 0) {
+        buf = strstr(mplayer_output->str, "ID_START_TIME");
+        sscanf(buf, "ID_START_TIME=%lf", &idledata->start_time);
+        g_idle_add(set_progress_time, idledata);
+    }
+
     if (strstr(mplayer_output->str, "ID_LENGTH") != 0) {
         buf = strstr(mplayer_output->str, "ID_LENGTH");
         sscanf(buf, "ID_LENGTH=%lf", &idledata->length);
+		if (idledata->streaming)
+			idledata->cachepercent = 0.0;
         g_idle_add(set_progress_time, idledata);
     }
 
@@ -501,6 +519,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         old_pos = idledata->position;
         buf = strstr(mplayer_output->str, "ANS_TIME_POSITION");
         sscanf(buf, "ANS_TIME_POSITION=%lf", &idledata->position);
+        idledata->position -= idledata->start_time;
         if (idledata->position < old_pos) {
             send_command("get_time_length\n", FALSE);
             state = PLAYING;
@@ -556,8 +575,10 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
     }
 
     if (strstr(mplayer_output->str, "ANS_switch_audio") != 0) {
+        //printf("%s\n", mplayer_output->str);
         buf = strstr(mplayer_output->str, "ANS_switch_audio");
         sscanf(buf, "ANS_switch_audio=%i", &idledata->switch_audio);
+        idledata->switch_audio--;
         g_idle_add(set_update_gui, NULL);
     }
 /*
@@ -567,6 +588,7 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
         g_idle_add(set_update_gui, NULL);
     }
 */
+
     if (strstr(mplayer_output->str, "ANS_brightness") != 0) {
         buf = strstr(mplayer_output->str, "ANS_brightness");
         sscanf(buf, "ANS_brightness=%i", &idledata->brightness);
@@ -713,6 +735,19 @@ gboolean thread_reader(GIOChannel * source, GIOCondition condition, gpointer dat
                 g_free(buf);
             }
         }
+        buf = strstr(mplayer_output->str, "_NAME=");
+        if (buf != NULL) {
+            buf += strlen("_NAME=");
+            menu->label = g_strdup(buf);
+            if (menu->label != NULL && strlen(menu->label) > 0) {
+                g_idle_add(set_new_audio_menu, menu);
+                if (alang != NULL && g_strrstr(alang, menu->label) != NULL) {
+                    buf = g_strdup_printf("switch_audio %i\n", menu->value);
+                    send_command(buf, TRUE);
+                    g_free(buf);
+                }
+            }
+        }
     }
 
     if (strstr(mplayer_output->str, "ID_AUDIO_ID=") != 0) {
@@ -950,7 +985,7 @@ gpointer launch_player(gpointer data)
             argv[arg++] = g_strdup_printf("ffmpeg12mc");
         } else {
             argv[arg++] = g_strdup_printf("-vo");
-            argv[arg++] = g_strdup_printf("xv,x11");
+            argv[arg++] = g_strdup_printf("xvmc,");
             if (!disable_deinterlace) {
                 argv[arg++] = g_strdup_printf("-vf-pre");
                 argv[arg++] = g_strdup_printf("yadif,softskip,scale");
@@ -960,28 +995,16 @@ gpointer launch_player(gpointer data)
 
     if (vo != NULL && g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0) {
         //printf("video_codec = '%s'\n",idledata->video_codec);
-        if (g_ascii_strcasecmp(idledata->video_codec, "ffmpeg1") == 0
-            || g_ascii_strcasecmp(idledata->video_codec, "ffmpeg2") == 0
-            || g_ascii_strcasecmp(idledata->video_codec, "mpegpes") == 0) {
-            argv[arg++] = g_strdup_printf("-vc");
-            argv[arg++] = g_strdup_printf("ffmpeg12vdpau");
-        } else if (g_ascii_strcasecmp(idledata->video_codec, "ffh264") == 0) {
-            argv[arg++] = g_strdup_printf("-vc");
-            argv[arg++] = g_strdup_printf("ffh264vdpau");
-        } else if (g_ascii_strcasecmp(idledata->video_codec, "ffwmv3") == 0) {
-            argv[arg++] = g_strdup_printf("-vc");
-            argv[arg++] = g_strdup_printf("ffwmv3vdpau");
-        } else if (g_ascii_strcasecmp(idledata->video_codec, "ffvc1") == 0) {
-            argv[arg++] = g_strdup_printf("-vc");
-            argv[arg++] = g_strdup_printf("ffvc1vdpau");
+
+        argv[arg++] = g_strdup_printf("-vo");
+        if (!disable_deinterlace) {
+            argv[arg++] = g_strdup_printf("vdpau:deint=2,");
         } else {
-            argv[arg++] = g_strdup_printf("-vo");
-            argv[arg++] = g_strdup_printf("vdpau,xv,x11");
-            if (!disable_deinterlace) {
-                argv[arg++] = g_strdup_printf("-vf-pre");
-                argv[arg++] = g_strdup_printf("yadif,softskip,scale");
-            }
+            argv[arg++] = g_strdup_printf("%s,vdpau,", vo);
         }
+
+        argv[arg++] = g_strdup_printf("-vc");
+        argv[arg++] = g_strdup_printf("ffmpeg12vdpau,ffh264vdpau,ffwmv3vdpau,ffvc1vdpau,");
     }
 
     if (use_hw_audio) {
@@ -1026,6 +1049,7 @@ gpointer launch_player(gpointer data)
 
     if (vo == NULL
         || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+             || g_ascii_strncasecmp(vo, "vaapi", strlen("vaapi")) == 0
              || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
         if (!disable_deinterlace) {
             argv[arg++] = g_strdup_printf("-vf-pre");
@@ -1140,7 +1164,9 @@ gpointer launch_player(gpointer data)
             argv[arg++] = g_strdup_printf("-ass-use-margins");
         }
         // Simply ommiting '-embeddedfonts' did not work
-        if (!disable_embeddedfonts && g_strrstr(idledata->demuxer, "mkv")) {
+        // printf("demuxer = %s\n",idledata->demuxer);
+        // if (!disable_embeddedfonts) {
+        if (!disable_embeddedfonts && (g_strrstr(idledata->demuxer, "mkv") || g_strrstr(idledata->demuxer, "lavfpref")) ) {
             argv[arg++] = g_strdup_printf("-embeddedfonts");
         } else {
             argv[arg++] = g_strdup_printf("-noembeddedfonts");
@@ -1210,6 +1236,7 @@ gpointer launch_player(gpointer data)
     }
 
     if (vo == NULL || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+                        || g_ascii_strncasecmp(vo, "vaapi", strlen("vvapi")) == 0
                         || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
 
         if (pplevel > 0) {
@@ -1230,6 +1257,7 @@ gpointer launch_player(gpointer data)
 
     if (vo == NULL
         || !(g_ascii_strncasecmp(vo, "xvmc", strlen("xvmc")) == 0
+             || g_ascii_strncasecmp(vo, "vaapi", strlen("vvapi")) == 0
              || g_ascii_strncasecmp(vo, "vdpau", strlen("vdpau")) == 0)) {
         argv[arg++] = g_strdup_printf("-vf-add");
         argv[arg++] = g_strdup_printf("screenshot");
@@ -1277,10 +1305,16 @@ gpointer launch_player(gpointer data)
         argv[arg++] = g_strdup_printf("QuickTime/7.6.4");
     }
 
+    /* disable msg stuff to make sure extra console characters don't mess around */
+    argv[arg++] = g_strdup_printf("-nomsgcolor");
+    argv[arg++] = g_strdup_printf("-nomsgmodule");
 
-    if (threaddata->playlist)
+
+    if (threaddata->playlist) {
+        argv[arg++] = g_strdup_printf("-cache");
+        argv[arg++] = g_strdup_printf("%i", cache_size);
         argv[arg++] = g_strdup_printf("-playlist");
-
+    }
 
     argv[arg] = g_strdup_printf("%s", threaddata->filename);
     argv[arg + 1] = NULL;
@@ -1496,6 +1530,14 @@ gpointer launch_player(gpointer data)
                 g_idle_add(play, p);
             }
 
+            if (playback_error == NO_ERROR) {
+                // nothing is on the playlist and we are not looping so ask plugin for next item
+                if (embed_window != 0 || control_id != 0) {
+                    dbus_send_event("MediaComplete", 0);
+                    dbus_open_next();
+                }
+            }
+
             dontplaynext = FALSE;
         }
 
